@@ -4,7 +4,7 @@ use warnings;
 
 package Mail::Message::TransferEnc::SevenBit;
 use vars '$VERSION';
-$VERSION = '2.059';
+$VERSION = '2.060';
 use base 'Mail::Message::TransferEnc';
 
 
@@ -34,7 +34,7 @@ sub encode($@)
     my $changes = 0;
 
     foreach ($body->lines)
-    {   $changes++ if s/[^\000-\127]/chr(ord($&) & 0x7f)/ge;
+    {   $changes++ if s/([^\000-\127])/chr(ord($1) & 0x7f)/ge;
         $changes++ if s/[\000\013]//g;
 
         $changes++ if length > 997;
